==> packageinstaller-pkglist-libre_0.1.3.tar.xz: packageinstaller-pkglist-libre/meld.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>  
Meld
</name>

<description>  
   <am>graphical tool to diff and merge files</am>
   <ar>graphical tool to diff and merge files</ar>
   <bg>graphical tool to diff and merge files</bg>
   <bn>graphical tool to diff and merge files</bn>
   <ca>Eina gràfica per a fer diff i merge de fitxers</ca>
   <cs>graphical tool to diff and merge files</cs>
   <da>grafisk værktøj til at se forskelle i og sammenføje filer</da>
   <de>Grafisches Werkzeug zum Vergleichen und Zusammenführen von Dateien</de>
   <el>γραφικό εργαλείο για τη διάχυση και συγχώνευση αρχείων</el>
   <en>graphical tool to diff and merge files</en>
   <es>Herramienta gráfica de comparación de archivos</es>
   <et>graphical tool to diff and merge files</et>
   <eu>graphical tool to diff and merge files</eu>
   <fa>graphical tool to diff and merge files</fa>
   <fil_PH>graphical tool to diff and merge files</fil_PH>
   <fi>graphical tool to diff and merge files</fi>
   <fr>Utilitaire graphique pour séparer et fusionner des dossiers</fr>
   <he_IL>graphical tool to diff and merge files</he_IL>
   <hi>graphical tool to diff and merge files</hi>
   <hr>graphical tool to diff and merge files</hr>
   <hu>graphical tool to diff and merge files</hu>
   <id>graphical tool to diff and merge files</id>
   <is>graphical tool to diff and merge files</is>
   <it>strumento grafico per valutare le differenze dei file attraverso diff e merge</it>
   <ja_JP>graphical tool to diff and merge files</ja_JP>
   <ja>graphical tool to diff and merge files</ja>
   <kk>graphical tool to diff and merge files</kk>
   <ko>graphical tool to diff and merge files</ko>
   <lt>graphical tool to diff and merge files</lt>
   <mk>graphical tool to diff and merge files</mk>
   <mr>graphical tool to diff and merge files</mr>
   <nb>graphical tool to diff and merge files</nb>
   <nl>grafisch hulpmiddel om bestanden te scheiden en samen te voegen</nl>
   <pl>graficzne narzędzie do porównywania i scalania plików</pl>
   <pt_BR>Ferramenta gráfica para comparar (diff) e integrar (merge) arquivos</pt_BR>
   <pt>Ferramenta gráfica para comparar (diff) e integrar (merge) ficheiros</pt>
   <ro>graphical tool to diff and merge files</ro>
   <ru>Графическая утилита для сравнения и слияния файлов и каталогов</ru>
   <sk>graphical tool to diff and merge files</sk>
   <sl>Grafično orodje za spajanje in ločevanje datotek</sl>
   <sq>graphical tool to diff and merge files</sq>
   <sr>graphical tool to diff and merge files</sr>
   <sv>grafiskt verktyg för att "diff" och "merge" filer</sv>
   <tr>graphical tool to diff and merge files</tr>
   <uk>графічний інструмент для порівняння та об’єднання файлів</uk>
   <vi>graphical tool to diff and merge files</vi>
   <zh_CN>graphical tool to diff and merge files</zh_CN>
   <zh_TW>graphical tool to diff and merge files</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
meld
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
meld
</uninstall_package_names>
</app>

==> packageinstaller-pkglist-libre_0.2.0.tar.xz: packageinstaller-pkglist-libre/meld.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>
Meld
</name>

<description>
   <am>graphical tool to diff and merge files</am>
   <ar>graphical tool to diff and merge files</ar>
   <be>graphical tool to diff and merge files</be>
   <bg>graphical tool to diff and merge files</bg>
   <bn>graphical tool to diff and merge files</bn>
   <ca>Eina gràfica per a fer diff i merge de fitxers</ca>
   <cs>graphical tool to diff and merge files</cs>
   <da>grafisk værktøj til at se forskelle i og sammenføje filer</da>
   <de>Grafisches Werkzeug zum Vergleichen und Zusammenführen von Dateien</de>
   <el>Γραφικό εργαλείο για σύγκριση και συγχώνευση αρχείων</el>
   <en>graphical tool to diff and merge files</en>
   <es_ES>Herramienta gráfica de comparación de archivos</es_ES>
   <es>Herramienta gráfica de comparación de archivos</es>
   <et>graphical tool to diff and merge files</et>
   <eu>graphical tool to diff and merge files</eu>
   <fa>graphical tool to diff and merge files</fa>
   <fil_PH>graphical tool to diff and merge files</fil_PH>
   <fi>graafinen työkalu tiedostojen erittelyyn ja yhdistelyyn</fi>
   <fr_BE>graphical tool to diff and merge files</fr_BE>
   <fr>Utilitaire graphique pour séparer et fusionner des dossiers</fr>
   <gl_ES>ferramenta gráfica para comparar e integrar ficheiros</gl_ES>
   <gu>graphical tool to diff and merge files</gu>
   <he_IL>graphical tool to diff and merge files</he_IL>
   <hi>graphical tool to diff and merge files</hi>
   <hr>graphical tool to diff and merge files</hr>
   <hu>graphical tool to diff and merge files</hu>
   <id>graphical tool to diff and merge files</id>
   <is>graphical tool to diff and merge files</is>
   <it>strumento grafico per valutare le differenze dei file attraverso diff e merge</it>
   <ja>ファイルの差分とマージを行うグラフィカルなツール</ja>
   <kk>graphical tool to diff and merge files</kk>
   <ko>graphical tool to diff and merge files</ko>
   <lt>graphical tool to diff and merge files</lt>
   <mk>graphical tool to diff and merge files</mk>
   <mr>graphical tool to diff and merge files</mr>
   <nb_NO>graphical tool to diff and merge files</nb_NO>
   <nb>Grafisk «diff» og fletting av forskjeller mellom filer</nb>
   <nl_BE>graphical tool to diff and merge files</nl_BE>
   <nl>grafisch hulpmiddel om bestanden te scheiden en samen te voegen</nl>
   <pl>graficzne narzędzie do porównywania i scalania plików</pl>
   <pt_BR>Ferramenta gráfica para diferenciar (diff) e mesclar (merge) arquivos</pt_BR>
   <pt>Ferramenta gráfica para comparar (diff) e integrar (merge) ficheiros</pt>
   <ro>graphical tool to diff and merge files</ro>
   <ru>Графическая утилита для сравнения и слияния файлов и каталогов</ru>
   <sk>graphical tool to diff and merge files</sk>
   <sl>Grafično orodje za spajanje in ločevanje datotek</sl>
   <sq>graphical tool to diff and merge files</sq>
   <sr>graphical tool to diff and merge files</sr>
   <sv>grafiskt verktyg för att "diff" och "merge" filer</sv>
   <th>graphical tool to diff and merge files</th>
   <tr>dosyaları ayırmak ve birleştirmek için grafiksel araç</tr>
   <uk>графічний інструмент для порівняння та об’єднання файлів</uk>
   <vi>graphical tool to diff and merge files</vi>
   <zh_CN>graphical tool to diff and merge files</zh_CN>
   <zh_HK>graphical tool to diff and merge files</zh_HK>
   <zh_TW>graphical tool to diff and merge files</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
meld
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
meld
</uninstall_package_names>
</app>
